@@ -213,12 +213,14 @@ class Pods:
             ))
         )
 
-    def wait_for_running(namespace: str, pod_name: str):
+    def wait_for_running(namespace: str, pod_name: str, msg: str=None):
         msged = False
 
         while Pods.get(namespace, pod_name).status.phase != 'Running':
             if not msged:
-                log2(f'Waiting for the {pod_name} pod to start up...')
+                if not msg:
+                    msg = f'Waiting for the {pod_name} pod to start up...'
+                log2(msg)
                 msged = True
             time.sleep(5)
 
